@@ -371,6 +371,33 @@ PROFILE_SAVE_AS_TITLE = _("Save Profile As")
 # name of a new settings profile being saved via the 'Save Profile As' dialog.
 PROFILE_NAME_LABEL = _("_Profile Name:")
 
+# Translators: Profiles in Orca make it possible for users to quickly switch
+# amongst a group of pre-defined settings (e.g. an 'English' profile for reading
+# text written in English using an English-language speech synthesizer and
+# braille rules, and a similar 'Spanish' profile for reading Spanish text.
+# The following is a title in a dialog informing the user that he/she
+# is about to remove a user profile, and action that cannot be undone.
+PROFILE_REMOVE_TITLE = _("Remove User Profile")
+
+# Translators: Profiles in Orca make it possible for users to quickly switch
+# amongst a group of pre-defined settings (e.g. an 'English' profile for reading
+# text written in English using an English-language speech synthesizer and
+# braille rules, and a similar 'Spanish' profile for reading Spanish text.
+# The following is a label in a dialog informing the user that he/she
+# is about to remove a user profile, and action that cannot be undone.
+PROFILE_REMOVE_LABEL = _("Remove user profile")
+
+# Translators: Profiles in Orca make it possible for users to quickly switch
+# amongst a group of pre-defined settings (e.g. an 'English' profile for reading
+# text written in English using an English-language speech synthesizer and
+# braille rules, and a similar 'Spanish' profile for reading Spanish text.
+# The following is a message in a dialog informing the user that he/she
+# is about to remove a user profile, an action that cannot be undone.
+PROFILE_REMOVE_MESSAGE = _("You are about to remove profile %s. " \
+                           "All unsaved settings and settings saved in this " \
+                           "profile will be lost. Do you want to continue " \
+                           "and remove this profile and all related settings?")
+
 # Translators: Orca has a setting which determines which progress bar updates
 # should be announced. Choosing "All" means that Orca will present progress bar
 # updates regardless of what application and window they happen to be in.
@@ -674,6 +701,11 @@ PAGE_NAVIGATION = _("Page Navigation")
 READ_PAGE_UPON_LOAD = \
     _("Automatically start speaking a page when it is first _loaded")
 
+# Translators: When the user loads a new web page, they can optionally have Orca
+# automatically summarize details about the page, such as the number of elements
+# (landmarks, forms, links, tables, etc.).
+PAGE_SUMMARY_UPON_LOAD = _("_Present summary of a page when it is first loaded")
+
 # Translators: Different speech systems and speech engines work differently when
 # it comes to handling pauses (e.g. sentence boundaries). This property allows
 # the user to specify whether speech should be sent to the speech synthesis
@@ -737,9 +769,18 @@ SPELL_CHECK_SPELL_SUGGESTION = _("Spell _suggestion")
 SPELL_CHECK_PRESENT_CONTEXT = _("Present _context of error")
 
 # Translators: This is a label for an option to tell Orca whether or not it
-# should speak the coordinates of the current spread sheet cell. Coordinates are
-# the row and column position within the spread sheet (i.e. A1, B1, C2 ...)
-SPREADSHEET_SPEAK_CELL_COORDINATES = _("Speak spread sheet cell coordinates")
+# should speak the coordinates of the current spreadsheet cell. Coordinates are
+# the row and column position within the spreadsheet (i.e. A1, B1, C2 ...)
+SPREADSHEET_SPEAK_CELL_COORDINATES = _("Speak spreadsheet cell coordinates")
+
+# Translators: This is a label for an option which controls what Orca speaks when
+# presenting selection changes in a spreadsheet. By default, Orca will speak just
+# what changed. For instance, if cells A1 through A8 are already selected, and the
+# user adds A9 to the selection, Orca by default would just say "A9 selected."
+# Some users, however, prefer to have Orca always announce the entire selected range,
+# i.e. in the same scenario say "A1 through A9 selected." Those users should enable
+# this option.
+SPREADSHEET_SPEAK_SELECTED_RANGE = _("Always speak selected spreadsheet range")
 
 # Translators: This is a label for an option for whether or not to speak the
 # header of a table cell in document content.
