@@ -44,11 +44,6 @@ activeWindow = None
 #
 activeScript = None
 
-# The "click" count. Used to determine if the user has double or triple
-# "clicked" a key.
-#
-clickCount = 0
-
 # Used to capture keys to redefine key bindings by the user.
 #
 capturingKeys   = False
@@ -67,10 +62,6 @@ lastInputEvent = None
 #
 bypassNextCommand = False
 
-# Records the last time a key was echoed.
-#
-lastKeyEchoTime = None
-
 # The last searchQuery
 #
 searchQuery = None
@@ -83,3 +74,5 @@ learnModeEnabled = False
 # Handle to the Orca Preferences Glade GUI object.
 #
 orcaOS = None
+
+listNotificationsModeEnabled = False
