@@ -10,19 +10,17 @@ __all__ = ['Banshee',
            'gedit',
            'gnome-documents',
            'gnome-keyring-ask',
-           'gnome-mud',
            'gnome-panel',
            'gnome-screensaver-dialog',
            'gnome-search-tool',
            'gnome-shell',
            'gnome-window-properties',
            'Instantbird',
-           'liferea',
+           'kwin',
            'Mozilla',
            'notification-daemon',
            'notify-osd',
            'pidgin',
-           'planner',
            'rhythmbox',
            'soffice',
            'SeaMonkey',
