@@ -35,8 +35,9 @@ class VoiceFamily(dict):
 
     NAME   = "name"
     GENDER = "gender"
-    LOCALE = "locale"
+    LANG   = "lang"
     DIALECT = "dialect"
+    VARIANT = "variant"
 
     MALE   = "male"
     FEMALE = "female"
@@ -44,8 +45,9 @@ class VoiceFamily(dict):
     settings = {
         NAME   : None,
         GENDER : None,
-        LOCALE : None,
+        LANG   : None,
         DIALECT: None,
+        VARIANT: None,
     }
 
     def __init__(self, props):
@@ -80,8 +82,9 @@ class SayAllContext:
         self.obj           = obj
         self.utterance     = utterance
         self.startOffset   = startOffset
-        self.currentOffset = startOffset
         self.endOffset     = endOffset
+        self.currentOffset = startOffset
+        self.currentEndOffset = None
 
 
 class SpeechServer(object):
